@@ -1,13 +1,13 @@
-import logging
-import sqlalchemy 
+import os
+import sqlalchemy
 import pandas as pd
-from trell import aws
 import mysql.connector
 
+from trell import aws
+from trell.utils import logger
 from trell.exceptions import MysqlConnectionError, MysqlDataFetchError, MysqlGenericError
-from trell.utils import LogFormatter
-LogFormatter.apply()
- 
+
+
 class MySQL:
 
     """MySQL database utility functions"""
@@ -17,35 +17,29 @@ class MySQL:
         initialisation method for MySQL Connector
         :param string db_string: mysql database connection string
         """
-        
+
         try:
             self.connection = sqlalchemy.create_engine(db_string)
         except Exception as err:
             raise MysqlConnectionError(err)
-        
 
     def get_data(self, query):
-
         """
         Fetch data from mysql as a dataframe.
         :param string query: query for fetching data from table
         :return pd.DataFrame data
         """
 
-       
-
         try:
             data = pd.read_sql(query + " ;", self.connection)
-            logging.debug("data fetched successfully")
+            logger.debug("data fetched successfully")
             return data
         except Exception as err:
             raise MysqlDataFetchError(err)
         finally:
             self.connection.dispose()
 
-
     def execute_query(self, query):
-
         """
         Execute a query in the mysql table
         :param string query: query for execution in the table
@@ -54,14 +48,13 @@ class MySQL:
 
         try:
             self.connection.execute(query)
-            logging.debug("query executed successfully")
+            logger.debug("query executed successfully")
         except Exception as err:
             raise MysqlGenericError(err)
         finally:
             self.connection.dispose()
 
     def dump_data(self, data, table_name, mode="append"):
-
         """
         Execute a query in the mysql table
         :param pd.DataFrame data: dataframe to be appended or replaced
@@ -70,11 +63,11 @@ class MySQL:
         :return None
         """
 
-
         try:
             connection = self.connection
-            data.to_sql(name=table_name, con=connection, if_exists=mode, index=False)
-            logging.debug("data dumped successfully")
+            data.to_sql(name=table_name, con=connection,
+                        if_exists=mode, index=False)
+            logger.debug("data dumped successfully")
         except Exception as err:
             raise MysqlGenericError(err)
         finally:
@@ -82,7 +75,6 @@ class MySQL:
 
     @staticmethod
     def get_prod_data_from_local(query):
-
         """
         Fetch data from production mysql from local machine via SSH tunnelling (or local port forwarding).
         :param string query: query for execution in the table
@@ -91,28 +83,27 @@ class MySQL:
 
         try:
             connection = mysql.connector.connect(user=aws.cred['DATA_USER'],
-                                                password=aws.cred['DATA_PWD'],
-                                                host="127.0.0.1",
-                                                port=aws.cred['PORT_1'],
-                                                database="trellDb")
-            
+                                                 password=aws.cred['DATA_PWD'],
+                                                 host="127.0.0.1",
+                                                 port=aws.cred['PORT_1'],
+                                                 database="trellDb")
+
             #connection = sqlalchemy.create_engine(aws.cred['LOCAL_PROD_DB_CONNECTION_STRING'])
         except Exception as err:
             raise MysqlConnectionError(err)
 
         try:
             df = pd.read_sql(query + " ;", connection)
-            logging.debug("data fetched successfully")
+            logger.debug("data fetched successfully")
             return df
         except Exception as err:
             raise MysqlDataFetchError(err)
         finally:
             connection.close()       # for mysql.connector
-            #connection.dispose()   # for sqlalchemy
+            # connection.dispose()   # for sqlalchemy
 
     @staticmethod
     def get_prod_data(query):
-
         """
         Fetch data from production mysql as a dataframe.
         :param string query: query for fetching data from table
@@ -120,13 +111,21 @@ class MySQL:
         """
 
         try:
-            connection = sqlalchemy.create_engine(aws.cred['DATA_PROD_DB_CONNECTION_STRING'])
+            try:
+                connection = sqlalchemy.create_engine(
+                    aws.cred['PROD_DB_READ_CONNECTION_STRING'])
+                logger.debug("Connected to prod mysql via aws secret manager")
+            except:
+                connection = sqlalchemy.create_engine(
+                    os.environ["PROD_DB_READ_CONNECTION_STRING"])
+                logger.debug(
+                    "Connected to prod mysql via environment variables")
         except Exception as err:
             raise MysqlConnectionError(err)
-        
+
         try:
             return pd.read_sql(query + " ;", connection)
-            logging.debug("data fetched successfully")
+            logger.debug("data fetched successfully")
         except Exception as err:
             raise MysqlDataFetchError(err)
         finally:
@@ -134,7 +133,6 @@ class MySQL:
 
     @staticmethod
     def execute_query_in_prod(query):
-
         """
         Execute a query in the production mysql table
         :param string query: query for execution in the table
@@ -142,13 +140,21 @@ class MySQL:
         """
 
         try:
-            connection = sqlalchemy.create_engine(aws.cred['DATA_PROD_DB_CONNECTION_STRING'])
+            try:
+                connection = sqlalchemy.create_engine(
+                    aws.cred['PROD_DB_WRITE_CONNECTION_STRING'])
+                logger.debug("Connected to prod mysql via aws secret manager")
+            except:
+                connection = sqlalchemy.create_engine(
+                    os.environ["PROD_DB_WRITE_CONNECTION_STRING"])
+                logger.debug(
+                    "Connected to prod mysql via environment variables")
         except Exception as err:
             raise MysqlConnectionError(err)
-        
+
         try:
             connection.execute(query)
-            logging.debug("data executed successfully")
+            logger.debug("data executed successfully")
         except Exception as err:
             raise MysqlGenericError(err)
         finally:
@@ -156,7 +162,6 @@ class MySQL:
 
     @staticmethod
     def dump_into_prod(data, table_name, mode="append"):
-
         """
         Push data into production mysql table
         :param pd.DataFrame data: dataframe to be appended or replaced
@@ -166,15 +171,23 @@ class MySQL:
         """
 
         try:
-            connection = sqlalchemy.create_engine(aws.cred['DATA_PROD_DB_CONNECTION_STRING'])
+            try:
+                connection = sqlalchemy.create_engine(
+                    aws.cred['PROD_DB_WRITE_CONNECTION_STRING'])
+                logger.debug("Connected to prod mysql via aws secret manager")
+            except:
+                connection = sqlalchemy.create_engine(
+                    os.environ["PROD_DB_WRITE_CONNECTION_STRING"])
+                logger.debug(
+                    "Connected to prod mysql via environment variables")
         except Exception as err:
             raise MysqlConnectionError(err)
-        
+
         try:
-            data.to_sql(name=table_name, con=connection, if_exists=mode, index=False)
-            logging.debug("data dumped successfully")
+            data.to_sql(name=table_name, con=connection,
+                        if_exists=mode, index=False)
+            logger.debug("data dumped successfully")
         except Exception as err:
             raise MysqlGenericError(err)
         finally:
             connection.dispose()
-
